---
title: 코드 정보
description: PG사/카드사/택배사/은행별 코드들을 확인할 수 있습니다.
targetVersions:
  - v1
---

[결제대행사별 빌링키 획득 규칙](https://developers.portone.io/opi/ko/support/code-info/pg)

[PG사별 은행코드](https://developers.portone.io/opi/ko/support/code-info/pg-1)

[PG사 코드](https://developers.portone.io/opi/ko/support/code-info/pg-2)

[카드사 코드](https://developers.portone.io/opi/ko/support/code-info/card-code)

[택배사 코드](https://developers.portone.io/opi/ko/support/code-info/code)

[PG사 오류코드](https://developers.portone.io/opi/ko/support/code-info/pg-3)

[해외 카드코드](https://developers.portone.io/opi/ko/support/code-info/portone-code)
